from iplogger.models import UserIP

class IPLoggerMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        response = self.get_response(request)
        ip_address = request.META.get('HTTP_X_FORWARDED_FOR') or request.META.get('REMOTE_ADDR')
        
        if ip_address:
            UserIP.objects.create(user=request.user, ip_address=ip_address)
        
        return response



from django.db import models

class UserIP(models.Model):
    user = models.ForeignKey('auth.User', on_delete=models.CASCADE)
    ip_address = models.GenericIPAddressField()
    timestamp = models.DateTimeField(auto_now_add=True)



from setuptools import setup, find_packages
setup(
    name='django-dc-iplogger',  # Update with your package name
   version='0.3.0',  # Update with the appropriate version
    packages=find_packages(),
    install_requires=[
        'Django',
    ],
    classifiers=[
        # ... (other classifiers)
        "License :: OSI Approved :: MIT License",
    ],
    python_requires='>=3.6',
    long_description=open('README.md').read(),  # Include README content
    license='MIT',  # Specify the license
)
